@@ -11,18 +11,6 @@ from PySFML import sf
 
 import os
 
-class Sonido:
-
-    def __init__(self, buffer):
-        self.buffer = buffer
-        self.sonido = sf.Sound(buffer)
-        pass
-
-    def reproducir(self):
-        self.sonido.Play()
-    
-    def Play(self):
-        self.reproducir()
 
 def cargar(ruta):
     """Carga un sonido para reproducir, donde el argumento ``ruta`` indica cual es el archivo.
@@ -34,9 +22,9 @@ def cargar(ruta):
         risa = pilas.sonidos.cargar("risa.ogg")
 
     En caso de éxito retorna el objeto Sound, que se puede
-    reproducir usando el método ``Play()``, por ejemplo::
+    reproducir usando el método ``reproducir()``, por ejemplo::
 
-        risa.Play()
+        risa.reproducir()
 
     El directorio de búsqueda del sonido sigue el siguiente orden:
 
@@ -46,8 +34,5 @@ def cargar(ruta):
 
     En caso de error genera una excepción de tipo IOError.
     """
-    path = pilas.utils.obtener_ruta_al_recurso(ruta)
-
-    buff = sf.SoundBuffer()
-    buff.LoadFromFile(path)
-    return Sonido(buff)
+    ruta = pilas.utils.obtener_ruta_al_recurso(ruta)
+    return pilas.motor.cargar_sonido(ruta)
